[Zope3-checkins] CVS: Zope3/src/zope/app/interfaces/workflow - __init__.py:1.15

Jim Fulton jim@zope.com
Sat, 21 Jun 2003 17:22:42 -0400


Update of /cvs-repository/Zope3/src/zope/app/interfaces/workflow
In directory cvs.zope.org:/tmp/cvs-serv2745/src/zope/app/interfaces/workflow

Modified Files:
	__init__.py 
Log Message:
Major refactoring to reflect change in terminology from
"configuration" to "registration" to refer to the configuration of how
objects are used (as opposed to their internal configuration).


=== Zope3/src/zope/app/interfaces/workflow/__init__.py 1.14 => 1.15 ===
--- Zope3/src/zope/app/interfaces/workflow/__init__.py:1.14	Thu May  1 15:35:23 2003
+++ Zope3/src/zope/app/interfaces/workflow/__init__.py	Sat Jun 21 17:22:11 2003
@@ -20,9 +20,9 @@
 from zope.interface import Interface
 from zope.interface import Attribute
 from zope.app.interfaces.container import IContainer
-from zope.app.interfaces.services.configuration \
-     import INamedComponentConfiguration
-from zope.app.interfaces.services.configuration import ComponentPath
+from zope.app.interfaces.services.registration \
+     import INamedComponentRegistration
+from zope.app.interfaces.services.registration import ComponentPath
 
 class IWorkflowService(Interface):
     """Workflow service.
@@ -49,8 +49,8 @@
         """
 
 
-class IProcessDefinitionConfiguration(INamedComponentConfiguration):
-    """Configuration for a workflow process definition.
+class IProcessDefinitionRegistration(INamedComponentRegistration):
+    """Registration for a workflow process definition.
     """
 
     componentPath = ComponentPath(